"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_server_core_1 = require("apollo-server-core");
const gql_1 = require("./gql");
function graphqlLodashExpress(options) {
    if (!options) {
        throw new Error('Apollo Server requires options.');
    }
    if (arguments.length > 1) {
        throw new Error(`Apollo Server expects exactly one argument, got ${arguments.length}`);
    }
    return (req, res, next) => {
        const originalQuery = req.method === 'POST' ? req.body : req.query;
        const { transform, apply } = gql_1.graphqlLodash(originalQuery.query, originalQuery.operationName);
        apollo_server_core_1.runHttpQuery([req, res], {
            method: req.method,
            options: options,
            query: originalQuery,
        })
            .then((gqlResponse) => {
            if (apply) {
                return JSON.stringify({
                    data: transform(JSON.parse(gqlResponse).data)
                });
            }
            else {
                return gqlResponse;
            }
        })
            .then((gqlResponse) => {
            res.setHeader('Content-Type', 'application/json');
            res.write(gqlResponse);
            res.end();
        }, (error) => {
            if ('HttpQueryError' !== error.name) {
                return next(error);
            }
            if (error.headers) {
                Object.keys(error.headers).forEach((header) => {
                    res.setHeader(header, error.headers[header]);
                });
            }
            res.statusCode = error.statusCode;
            res.write(error.message);
            res.end();
        });
    };
}
exports.graphqlLodashExpress = graphqlLodashExpress;
//# sourceMappingURL=express.js.map